@@ -17,7 +17,7 @@ case "$1" in
         exit ${OUT}
         ;;
     *)
-        bsjack daemon.usage
+        echo "Usage: {start|stop|reload|restart}"
         exit 1
     ;;
 esac
