@@ -8,7 +8,7 @@ from fabric.contrib.console import confirm
 from ground_soil.fabric import eval_kwargs, virtual_env
 from ground_soil.filesystem import temporary_directory, render_file, sed
 from beanstalk import IDENTIFIER, BEANSTALK_ROOT_PATH, BEANSTALK_GLOBAL_BASE_PATH
-from beanstalk.decorators import beanstalk_role
+from beanstalk.decorators import beanstalk_task
 from beanstalk.paths.server import (project_base_path, project_source_path, project_logs_path, project_venv_path,
                                     project_uwsgi_path, apache_conf_path, project_run_path)
 from beanstalk.tasks.utils import load_role_settings, set_verbose_level, run_hooked_actions
@@ -19,8 +19,7 @@ from beanstalk.console.titles import tool_title, section_title, separator
 #-----------------------------------------------------------------------------------------------------------------------
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def setup(settings_path=None, **settings_patches):
     """Setup remote base of beanstalk-stack in this server
     """
@@ -187,8 +186,7 @@ def setup(settings_path=None, **settings_patches):
     run_hooked_actions('POST_SETUP_ACTIONS')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def create_app(project_name, settings_path=None, **settings_patches):
     """Create an app
     """
@@ -241,8 +239,7 @@ def create_app(project_name, settings_path=None, **settings_patches):
     run_hooked_actions('POST_CREATE_ACTIONS')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def delete_app(project_name, settings_path=None, **settings_patches):
     """Delete an app
     """
@@ -263,8 +260,7 @@ def delete_app(project_name, settings_path=None, **settings_patches):
         local('rm -rf %s' % project_base)
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def install_app(project_name, settings_path=None, **settings_patches):
     """Install an app (call when u updated the code)
     """
@@ -336,8 +332,7 @@ def install_app(project_name, settings_path=None, **settings_patches):
     run_hooked_actions('POST_INSTALL_ACTIONS')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def reload_app(project_name, settings_path=None, **settings_patches):
     """Update an app (call when u updated the code)
     """
@@ -354,8 +349,7 @@ def reload_app(project_name, settings_path=None, **settings_patches):
     run_hooked_actions('POST_RELOAD_ACTIONS')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def commit_app(project_name, settings_path=None, **settings_patches):
     """Commit app
     """
@@ -373,8 +367,7 @@ def commit_app(project_name, settings_path=None, **settings_patches):
     run_hooked_actions('POST_COMMIT_ACTION')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def activate_app(project_name, settings_path=None, **settings_patches):
     """Add app to apache httpd
     """
@@ -402,8 +395,7 @@ def activate_app(project_name, settings_path=None, **settings_patches):
         local('sudo /usr/sbin/httpd_reload')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def deactivate_app(project_name, settings_path=None, **settings_patches):
     """Remove app from apache httpd
     """
@@ -413,8 +405,7 @@ def deactivate_app(project_name, settings_path=None, **settings_patches):
     local('sudo /usr/sbin/httpd_reload')
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def build_venv(project_name, settings_path=None, **settings_patches):
     """Build virtual env of target app.
     """
@@ -438,8 +429,7 @@ def build_venv(project_name, settings_path=None, **settings_patches):
             local('pip intall -r %s' % requirments_path)
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def app_info(project_name, settings_path=None, **settings_patches):
     """Get info of an app
     """
@@ -483,8 +473,7 @@ def app_info(project_name, settings_path=None, **settings_patches):
         print separator('-', 40)
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def list_apps(settings_path=None, **settings_patches):
     """Get list of apps
     """
@@ -500,8 +489,7 @@ def list_apps(settings_path=None, **settings_patches):
         print app
 
 
-@task
-@beanstalk_role('server')
+@beanstalk_task(beanstalk_role='server')
 def add_user(tmp_key_path, clean_tmp_key=False):
     """Add a user's SSH public key to beanstalk
     """
